@@ -1077,12 +1077,12 @@ the mode-line will be setup."
   (add-hook 'comint-output-filter-functions 'sml/generate-buffer-identification)
   (add-hook 'eshell-directory-change-hook 'sml/generate-buffer-identification)
 
-  ;; Term support
-  (defadvice term-command-hook (after sml/term-advice-1 activate)
-    (sml/generate-buffer-identification))
+  ;; ;; Term support - Disabled for now because of Issue#198
+  ;; (defadvice term-command-hook (after sml/term-advice-1 activate)
+  ;;   (sml/generate-buffer-identification))
 
-  (defadvice term-handle-ansi-terminal-messages (after sml/term-advice-2 activate)
-    (sml/generate-buffer-identification))
+  ;; (defadvice term-handle-ansi-terminal-messages (after sml/term-advice-2 activate)
+  ;;   (sml/generate-buffer-identification))
 
   ;; Dired overrides the buffer-identification (which we would
   ;; normally respect) but doesn't actually do anything useful with
@@ -1415,7 +1415,8 @@ To be used in mapcar and accumulate results."
 
    ;;;; mode-line-position
    ;; Color the position percentage
-   ((sml/is-%p-p el)
+   ((or (sml/is-%p-p el)
+        (and (listp el) (memq 'mode-line-percent-position el)))
     `(sml/position-percentage-format
       (-3 (:propertize (:eval sml/position-percentage-format)
                        local-map ,mode-line-column-line-number-mode-map
@@ -1453,7 +1454,10 @@ mouse-3: Describe current input method"))
    ;; Color the mode line process
    ((or (equal el '("" mode-line-process))
         (equal (car (cdr-safe el)) '("" mode-line-process)))
-    `(:propertize ("" mode-line-process) face sml/process))
+    '(mode-line-process
+      (:eval (let ((text (format-mode-line mode-line-process)))
+               (add-face-text-property 0 (length text) 'sml/process t text)
+               text))))
    ;; Color the mode name, without changing other properties
    ((and (listp el)
          (equal (car el) :propertize)
@@ -1648,7 +1652,9 @@ project name first."
         (setq out (replace-regexp-in-string (car cur) (car (cdr cur)) out))))
     ;; Try truename replacements
     (when (string= out in)
-      (let* ((true-in (abbreviate-file-name (file-truename in)))
+      (let* ((true-in (abbreviate-file-name (if (file-remote-p in)
+                                                in
+                                              (file-truename in))))
              (true-out true-in))
         (dolist (cur sml/replacer-regexp-list)
           (setq true-out (replace-regexp-in-string
